import numpy as np

from mu_map.file.convert import dicom_to_interfile
from mu_map.file.dicom import is_dicom, load_dcm, load_dcm_img
from mu_map.file.interfile import load_interfile, load_interfile_img, Interfile


def load_as_interfile(filename: str) -> Interfile:
    """
    Load a file as an Interfile image even if it is
    in DICOM format.

    Parameters
    ----------
    filename: str
        the file to be loaded in Interfile format

    Returns
    -------
    Interfile
    """
    if is_dicom(filename):
        return dicom_to_interfile(*load_dcm(filename))
    else:
        return load_interfile(filename)


def load_img(filename: str, **kwargs) -> np.ndarray:
    """
    Load a file as a numpy array.

    Parameters
    ----------
    filename: str
        filename: the file to be loaded
    kwargs
        parameters passed to load_dcm_img if the file is a DICOM file

    Return
    ------
    np.ndarray
    """
    if is_dicom(filename):
        return load_dcm_img(filename, **kwargs)
    else:
        return load_interfile_img(filename)
